SimpleClipPath class

Inheritance

Constructors

SimpleClipPath({ClipPathType type = ClipPathType.ROUNDED_DOWN, double radius = 20.0, double topLeftPercentOfHeight = 0.0, double bottomLeftPercentOfHeight = 100.0, double topRightPercentOfHeight = 0.0, double bottomRightPercentOfHeight = 100.0})
const

Properties

bottomLeftPercentOfHeight → double
final
bottomRightPercentOfHeight → double
final
hashCode → int
The hash code for this object.
no setterinherited
radius → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topLeftPercentOfHeight → double
final
topRightPercentOfHeight → double
final
type → ClipPathType
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to reclip.
inherited
getApproximateClipRect(Size size) → Rect
Returns an approximation of the clip returned by getClip, as an axis-aligned Rect. This is used by the semantics layer to determine whether widgets should be excluded.
inherited
getBoilerPlate(Size size) → Path
getClip(Size size) → Path
Returns a description of the clip given that the render object being clipped is of the given size.
override
getClouds(Size size) → Path
getDiagonal(Size size) → Path
getJagged(Size size) → Path
getNone(Size size) → Path
getRoundedCorners(Size size) → Path
getRoundedDown(Size size) → Path
getRoundedShield(Size size) → Path
getRoundedUp(Size size) → Path
getTriangleDown(Size size) → Path
getWave(Size size) → Path
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to reclip.
inherited
shouldReclip(covariant CustomClipper<Path> oldClipper) → bool
Called whenever a new instance of the custom clipper delegate class is provided to the clip object, or any time that a new clip object is created with a new instance of the custom clipper delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited