ThemedEditableLabelValue class

Inheritance

Constructors

ThemedEditableLabelValue({Key? key, bool showLabel = true, String labelText = "", ThemeGroupType labelType = ThemeGroupType.MOM, Emphasis labelEmphasis = Emphasis.HIGH, TextAlign labelTextAlign = TextAlign.start, IconData? prefixIcon, ThemeGroupType prefixIconType = ThemeGroupType.MOM, Emphasis prefixIconEmphasis = Emphasis.HIGH, String text = "", ThemeGroupType textType = ThemeGroupType.MOM, Emphasis textEmphasis = Emphasis.HIGH, TextAlign textAlign = TextAlign.start, bool obscureText = false, String hintText = "", ThemeGroupType hintTextType = ThemeGroupType.MOM, Emphasis hintTextEmphasis = Emphasis.NONE, ThemeGroupType backgroundType = ThemeGroupType.MOM, ValueChanged<String>? onStringChangedCallback, FormFieldValidator<String>? validator})
const

Properties

backgroundType → ThemeGroupType
final
hashCode → int
The hash code for this object.
no setterinherited
hintText → String
final
hintTextEmphasis → Emphasis
final
hintTextType → ThemeGroupType
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelEmphasis → Emphasis
final
labelText → String
final
labelTextAlign → TextAlign
final
labelType → ThemeGroupType
final
obscureText → bool
final
onStringChangedCallback → ValueChanged<String>?
final
prefixIcon → IconData?
final
prefixIconEmphasis → Emphasis
final
prefixIconType → ThemeGroupType
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showLabel → bool
final
text → String
final
textAlign → TextAlign
final
textEmphasis → Emphasis
final
textType → ThemeGroupType
final
validator → FormFieldValidator<String>?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → ThemedEditableLabelValueState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited