HeaderList class

Inheritance

Constructors

HeaderList(List<ListItemModel> listItems, {Key? key, String? imageUrl, Color? imageBlendColor, BlendMode? imageBlendMode, BackgroundGradientType? headerGradientType, EdgeInsetsGeometry? headerPadding, EdgeInsetsGeometry? avatarPadding, SimpleClipPath? imageClipPath, int headerFlex = 1, AlignmentGeometry headerAlignment = AlignmentDirectional.bottomCenter, int itemsFlex = 2, EdgeInsetsGeometry? listPadding, ThemeGroupType cardType = ThemeGroupType.MOM, ElevationLevel cardElevationLevel = ElevationLevel.FLAT, ThemeGroupType leadingIconType = ThemeGroupType.MOM, Emphasis leadingEmphasis = Emphasis.NONE, ThemeGroupType titleType = ThemeGroupType.MOM, Emphasis titleEmphasis = Emphasis.NONE, ThemeGroupType subtitleType = ThemeGroupType.MOM, Emphasis subtitleEmphasis = Emphasis.NONE, ThemeGroupType trailingIconType = ThemeGroupType.MOM, Emphasis trailingEmphasis = Emphasis.NONE, bool isHeaderSticky = true, bool isAvatarEnabled = true, double? heightBetween = 20.0, String avatarTitle = "First Last Name", ThemeGroupType avatarTitleType = ThemeGroupType.POM, Emphasis avatarTitleEmphasis = Emphasis.HIGH, String avatarSubtitle = "Tag Line", ThemeGroupType avatarSubtitleType = ThemeGroupType.MOM, Emphasis avatarSubtitleEmphasis = Emphasis.NONE, String avatarImageUrl = "assets/female.png", double avatarImageBorderWidth = 4.0, double avatarImageRadius = 70.0, VoidCallback? avatarClickedCallback, bool usePolygonAvatar = false})
const

Properties

avatarClickedCallback → VoidCallback?
final
avatarImageBorderWidth → double
final
avatarImageRadius → double
final
avatarImageUrl → String
final
avatarPadding → EdgeInsetsGeometry?
final
avatarSubtitle → String
final
avatarSubtitleEmphasis → Emphasis
final
avatarSubtitleType → ThemeGroupType
final
avatarTitle → String
final
avatarTitleEmphasis → Emphasis
final
avatarTitleType → ThemeGroupType
final
cardElevationLevel → ElevationLevel
final
cardType → ThemeGroupType
final
hashCode → int
The hash code for this object.
no setterinherited
headerAlignment → AlignmentGeometry
final
headerFlex → int
final
headerGradientType → BackgroundGradientType?
final
headerPadding → EdgeInsetsGeometry?
final
heightBetween → double?
final
imageBlendColor → Color?
final
imageBlendMode → BlendMode?
final
imageClipPath → SimpleClipPath?
final
imageUrl → String?
final
isAvatarEnabled → bool
final
isHeaderSticky → bool
final
itemsFlex → int
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leadingEmphasis → Emphasis
final
leadingIconType → ThemeGroupType
final
listItems → List<ListItemModel>
final
listPadding → EdgeInsetsGeometry?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitleEmphasis → Emphasis
final
subtitleType → ThemeGroupType
final
titleEmphasis → Emphasis
final
titleType → ThemeGroupType
final
trailingEmphasis → Emphasis
final
trailingIconType → ThemeGroupType
final
usePolygonAvatar → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → HeaderListState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited