ListItemModel class

Constructors

ListItemModel({VoidCallback? itemClickedCallback, VoidCallback? itemLongClickedCallback, IconData? leadingIcon, VoidCallback? leadingIconClickedCallback, String? title, String? subtitle, IconData? trailingIcon, VoidCallback? trailingIconClickedCallback, ThemeGroupType? cardType, ElevationLevel? elevationLevel, ThemeGroupType? leadingIconType, Emphasis? leadingEmphasis, ThemeGroupType? titleType, Emphasis? titleEmphasis, ThemeGroupType? subtitleType, Emphasis? subtitleEmphasis, ThemeGroupType? trailingIconType, Emphasis? trailingEmphasis, EdgeInsetsGeometry? margin})

Properties

cardType ↔ ThemeGroupType?
getter/setter pair
elevationLevel ↔ ElevationLevel?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemClickedCallback ↔ VoidCallback?
getter/setter pair
itemLongClickedCallback ↔ VoidCallback?
getter/setter pair
leadingEmphasis ↔ Emphasis?
getter/setter pair
leadingIcon ↔ IconData?
getter/setter pair
leadingIconClickedCallback ↔ VoidCallback?
getter/setter pair
leadingIconType ↔ ThemeGroupType?
getter/setter pair
margin ↔ EdgeInsetsGeometry?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle ↔ String?
getter/setter pair
subtitleEmphasis ↔ Emphasis?
getter/setter pair
subtitleType ↔ ThemeGroupType?
getter/setter pair
title ↔ String?
getter/setter pair
titleEmphasis ↔ Emphasis?
getter/setter pair
titleType ↔ ThemeGroupType?
getter/setter pair
trailingEmphasis ↔ Emphasis?
getter/setter pair
trailingIcon ↔ IconData?
getter/setter pair
trailingIconClickedCallback ↔ VoidCallback?
getter/setter pair
trailingIconType ↔ ThemeGroupType?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited