ProfileScreen class

Inheritance

Constructors

ProfileScreen({Key? key, String screenTitle = "Profile", bool showLabels = true, ThemeGroupType labelType = ThemeGroupType.MOP, Emphasis labelEmphasis = Emphasis.NONE, TextAlign labelTextAlign = TextAlign.start, bool? showIcons, ThemeGroupType prefixIconType = ThemeGroupType.MOM, Emphasis prefixIconEmphasis = Emphasis.NONE, ThemeGroupType textType = ThemeGroupType.POM, Emphasis textEmphasis = Emphasis.HIGH, TextAlign textAlign = TextAlign.start, ThemeGroupType textFieldBackgroundType = ThemeGroupType.MOP, ThemeGroupType valueTextType = ThemeGroupType.MOP, Emphasis valueTextEmphasis = Emphasis.HIGH, TextAlign valueTextAlign = TextAlign.start, bool? showHints, ThemeGroupType hintTextType = ThemeGroupType.MOM, Emphasis hintTextEmphasis = Emphasis.NONE, String email = "", bool showEmail = true, bool canEditEmail = true, bool obscureEmail = false, ValueChanged<String>? onEmailChangedCallback, String emailLabel = "Email", bool? showEmailLabel, String emailHint = "Email", bool? showEmailHint, IconData? emailIcon = Icons.email, bool? showEmailIcon, bool validateEmail = true, String invalidEmailText = "Email is required", String password = "", bool showPassword = true, bool canEditPassword = true, bool obscurePassword = false, ValueChanged<String>? onPasswordChangedCallback, String passwordLabel = "Password", bool? showPasswordLabel, String passwordHint = "Password", bool? showPasswordHint, IconData? passwordIcon = Icons.password, bool? showPasswordIcon, bool validatePassword = true, String invalidPasswordText = "Enter a password 6+ chars long", int passwordMinimumLength = 6, String firstName = "", bool showFirstName = true, bool canEditFirstName = true, bool obscureFirstName = false, ValueChanged<String>? onFirstNameChangedCallback, String firstNameLabel = "First Name", bool? showFirstNameLabel, String firstNameHint = "First Name", bool? showFirstNameHint, IconData? firstNameIcon, bool? showFirstNameIcon, bool validateFirstName = true, String invalidFirstNameText = "First name is required", String lastName = "", bool showLastName = true, bool canEditLastName = true, bool obscureLastName = false, ValueChanged<String>? onLastNameChangedCallback, String lastNameLabel = "Last Name", bool? showLastNameLabel, String lastNameHint = "Last Name", bool? showLastNameHint, IconData? lastNameIcon, bool? showLastNameIcon, bool validateLastName = true, String invalidLastNameText = "Last name is required", String tagline = "", bool showTagline = true, bool canEditTagline = true, bool obscureTagline = false, ValueChanged<String>? onTaglineChangedCallback, String taglineLabel = "Tagline", bool? showTaglineLabel, String taglineHint = "Tagline", bool? showTaglineHint, IconData? taglineIcon, bool? showTaglineIcon, String pronouns = "", bool showPronouns = true, bool canEditPronouns = true, bool obscurePronouns = false, ValueChanged<String>? onPronounsChangedCallback, String pronounsLabel = "Pronouns", bool? showPronounsLabel, String pronounsHint = "Pronouns", bool? showPronounsHint, IconData? pronounsIcon, bool? showPronounsIcon, String organization = "", bool showOrganization = true, bool canEditOrganization = true, bool obscureOrganization = false, ValueChanged<String>? onOrganizationChangedCallback, String organizationLabel = "Organization", bool? showOrganizationLabel, String organizationHint = "Organization", bool? showOrganizationHint, IconData? organizationIcon, bool? showOrganizationIcon, String address = "", bool showAddress = true, bool canEditAddress = true, bool obscureAddress = false, ValueChanged<String>? onAddressChangedCallback, String addressLabel = "Address", bool? showAddressLabel, String addressHint = "Address", bool? showAddressHint, IconData? addressIcon, bool? showAddressIcon, String city = "", bool showCity = true, bool canEditCity = true, bool obscureCity = false, ValueChanged<String>? onCityChangedCallback, String cityLabel = "City", bool? showCityLabel, String cityHint = "City", bool? showCityHint, IconData? cityIcon, bool? showCityIcon, String state = "", bool showState = true, bool canEditState = true, bool obscureState = false, ValueChanged<String>? onStateChangedCallback, String stateLabel = "State", bool? showStateLabel, String stateHint = "State", bool? showStateHint, IconData? stateIcon, bool? showStateIcon, String zip = "", bool showZip = true, bool canEditZip = true, bool obscureZip = false, ValueChanged<String>? onZipChangedCallback, String zipLabel = "Zip", bool? showZipLabel, String zipHint = "Zip", bool? showZipHint, IconData? zipIcon, bool? showZipIcon, bool validateZip = true, String invalidZipText = "Zip is required", String logoutText = "Logout", VoidCallback? onTapLogout, String editText = "Edit", VoidCallback? onTapEdit, String saveText = "Save", VoidCallback? onTapSave, String deleteAccount = "Delete", VoidCallback? onTapDeleteAccount, bool doShowLoginRegisterButtons = true, EdgeInsets padding = const EdgeInsets.symmetric(vertical: 0.0, horizontal: paddingMini), bool isHeaderSticky = true, bool isFooterSticky = true, bool isFooterVertical = false, EdgeInsets headerPadding = const EdgeInsets.all(paddingMini), EdgeInsets footerPadding = const EdgeInsets.all(paddingMini), bool centerForm = true, bool isEditMode = false})
const

Properties

address → String
final
addressHint → String
final
addressIcon → IconData?
final
addressLabel → String
final
canEditAddress → bool
final
canEditCity → bool
final
canEditEmail → bool
final
canEditFirstName → bool
final
canEditLastName → bool
final
canEditOrganization → bool
final
canEditPassword → bool
final
canEditPronouns → bool
final
canEditState → bool
final
canEditTagline → bool
final
canEditZip → bool
final
centerForm → bool
final
city → String
final
cityHint → String
final
cityIcon → IconData?
final
cityLabel → String
final
deleteAccount → String
final
doShowLoginRegisterButtons → bool
final
editText → String
final
email → String
final
emailHint → String
final
emailIcon → IconData?
final
emailLabel → String
final
firstName → String
final
firstNameHint → String
final
firstNameIcon → IconData?
final
firstNameLabel → String
final
footerPadding → EdgeInsets
final
hashCode → int
The hash code for this object.
no setterinherited
headerPadding → EdgeInsets
final
hintTextEmphasis → Emphasis
final
hintTextType → ThemeGroupType
final
invalidEmailText → String
final
invalidFirstNameText → String
final
invalidLastNameText → String
final
invalidPasswordText → String
final
invalidZipText → String
final
isEditMode → bool
final
isFooterSticky → bool
final
isFooterVertical → bool
final
isHeaderSticky → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelEmphasis → Emphasis
final
labelTextAlign → TextAlign
final
labelType → ThemeGroupType
final
lastName → String
final
lastNameHint → String
final
lastNameIcon → IconData?
final
lastNameLabel → String
final
logoutText → String
final
obscureAddress → bool
final
obscureCity → bool
final
obscureEmail → bool
final
obscureFirstName → bool
final
obscureLastName → bool
final
obscureOrganization → bool
final
obscurePassword → bool
final
obscurePronouns → bool
final
obscureState → bool
final
obscureTagline → bool
final
obscureZip → bool
final
onAddressChangedCallback → ValueChanged<String>?
final
onCityChangedCallback → ValueChanged<String>?
final
onEmailChangedCallback → ValueChanged<String>?
final
onFirstNameChangedCallback → ValueChanged<String>?
final
onLastNameChangedCallback → ValueChanged<String>?
final
onOrganizationChangedCallback → ValueChanged<String>?
final
onPasswordChangedCallback → ValueChanged<String>?
final
onPronounsChangedCallback → ValueChanged<String>?
final
onStateChangedCallback → ValueChanged<String>?
final
onTaglineChangedCallback → ValueChanged<String>?
final
onTapDeleteAccount → VoidCallback?
final
onTapEdit → VoidCallback?
final
onTapLogout → VoidCallback?
final
onTapSave → VoidCallback?
final
onZipChangedCallback → ValueChanged<String>?
final
organization → String
final
organizationHint → String
final
organizationIcon → IconData?
final
organizationLabel → String
final
padding → EdgeInsets
final
password → String
final
passwordHint → String
final
passwordIcon → IconData?
final
passwordLabel → String
final
passwordMinimumLength → int
final
prefixIconEmphasis → Emphasis
final
prefixIconType → ThemeGroupType
final
pronouns → String
final
pronounsHint → String
final
pronounsIcon → IconData?
final
pronounsLabel → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saveText → String
final
screenTitle → String
final
showAddress → bool
final
showAddressHint → bool?
final
showAddressIcon → bool?
final
showAddressLabel → bool?
final
showCity → bool
final
showCityHint → bool?
final
showCityIcon → bool?
final
showCityLabel → bool?
final
showEmail → bool
final
showEmailHint → bool?
final
showEmailIcon → bool?
final
showEmailLabel → bool?
final
showFirstName → bool
final
showFirstNameHint → bool?
final
showFirstNameIcon → bool?
final
showFirstNameLabel → bool?
final
showHints → bool?
final
showIcons → bool?
final
showLabels → bool
final
showLastName → bool
final
showLastNameHint → bool?
final
showLastNameIcon → bool?
final
showLastNameLabel → bool?
final
showOrganization → bool
final
showOrganizationHint → bool?
final
showOrganizationIcon → bool?
final
showOrganizationLabel → bool?
final
showPassword → bool
final
showPasswordHint → bool?
final
showPasswordIcon → bool?
final
showPasswordLabel → bool?
final
showPronouns → bool
final
showPronounsHint → bool?
final
showPronounsIcon → bool?
final
showPronounsLabel → bool?
final
showState → bool
final
showStateHint → bool?
final
showStateIcon → bool?
final
showStateLabel → bool?
final
showTagline → bool
final
showTaglineHint → bool?
final
showTaglineIcon → bool?
final
showTaglineLabel → bool?
final
showZip → bool
final
showZipHint → bool?
final
showZipIcon → bool?
final
showZipLabel → bool?
final
state → String
final
stateHint → String
final
stateIcon → IconData?
final
stateLabel → String
final
tagline → String
final
taglineHint → String
final
taglineIcon → IconData?
final
taglineLabel → String
final
textAlign → TextAlign
final
textEmphasis → Emphasis
final
textFieldBackgroundType → ThemeGroupType
final
textType → ThemeGroupType
final
validateEmail → bool
final
validateFirstName → bool
final
validateLastName → bool
final
validatePassword → bool
final
validateZip → bool
final
valueTextAlign → TextAlign
final
valueTextEmphasis → Emphasis
final
valueTextType → ThemeGroupType
final
zip → String
final
zipHint → String
final
zipIcon → IconData?
final
zipLabel → String
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → ProfileScreenState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited